<!--
 Copyright European Organization for Nuclear Research (CERN)

 Licensed under the Apache License, Version 2.0 (the "License");
 You may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 http://www.apache.org/licenses/LICENSE-2.0

 Authors:
 - Mario Lassnig, <mario.lassnig@cern.ch>, 2014
-->

$var title: Index
$var script: <script src="/static/index.js"></script>

<center>
  <div id="gridview" style="width: 50%; height: 50%;">[loading]</div>
</center>
