
'''
This file is automatically generated by setup.py, So don't edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.11.1',
    'branch_nick': '(detached',
    'revision_id': 'b5d871ff29cd86c51dd5638bd351e776d527a3b4',
    'revno': 5048
}
